@@ -12,6 +12,7 @@ from argo.workflows.client import (
     V1alpha1Backoff,
     V1alpha1DAGTask,
     V1alpha1Inputs,
+    V1alpha1Metadata,
     V1alpha1Outputs,
     V1alpha1Parameter,
     V1alpha1RetryStrategy,
@@ -81,6 +82,8 @@ class Task:
         requires GPU resources, clients are encouraged to add a node selector for a node that can satisfy the
         requested resources. In addition, clients are encouraged to specify a GPU toleration, depending on the platform
         they submit the workflow to.
+    labels: Optional[Dict[str, str]] = None
+        A Dict of labels to attach to the Task Template object metadata
     """
 
     def __init__(
@@ -100,6 +103,7 @@ class Task:
         retry: Optional[Retry] = None,
         tolerations: Optional[List[Toleration]] = None,
         node_selectors: Optional[Dict[str, str]] = None,
+        labels: Optional[Dict[str, str]] = None,
     ):
         self.name = name.replace("_", "-")  # RFC1123
         self.func = func
@@ -118,6 +122,7 @@ class Task:
         self.retry = retry
         self.tolerations = tolerations
         self.node_selectors = node_selectors
+        self.labels = labels
 
         self.parameters = self.get_parameters()
         self.argo_input_artifacts = self.get_argo_input_artifacts()
@@ -498,6 +503,8 @@ class Task:
             volumes.append(self.resources.existing_volume.get_mount())
         if self.resources.empty_dir_volume:
             volumes.append(self.resources.empty_dir_volume.get_mount())
+        if self.resources.secret_volume:
+            volumes.append(self.resources.secret_volume.get_mount())
         return volumes
 
     def get_script_def(self) -> V1alpha1ScriptTemplate:
@@ -538,6 +545,7 @@ class Task:
             node_selector=self.node_selectors,
             tolerations=self.get_tolerations(),
             retry_strategy=self.get_retry_strategy(),
+            metadata=V1alpha1Metadata(labels=self.labels),
         )
 
     def get_retry_strategy(self) -> Optional[V1alpha1RetryStrategy]:
