@@ -1,5 +1,5 @@
 """The implementation of a Hera workflow for Argo-based workflows"""
-from typing import Optional
+from typing import Dict, Optional
 from uuid import uuid4
 
 from argo.workflows.client import (
@@ -32,15 +32,23 @@ class Workflow:
         The number of parallel tasks to run in case a task group is executed for multiple tasks.
     service_account_name: Optional[str] = None
         The name of the service account to use in all workflow tasks.
+    labels: Optional[Dict[str, str]] = None
+        A Dict of labels to attach to the Workflow object metadata
     """
 
     def __init__(
-        self, name: str, service: WorkflowService, parallelism: int = 50, service_account_name: Optional[str] = None
+        self,
+        name: str,
+        service: WorkflowService,
+        parallelism: int = 50,
+        service_account_name: Optional[str] = None,
+        labels: Optional[Dict[str, str]] = None,
     ):
         self.name = f'{name.replace("_", "-")}-{str(uuid4()).split("-")[0]}'  # RFC1123
         self.service = service
         self.parallelism = parallelism
         self.service_account_name = service_account_name
+        self.labels = labels
 
         self.dag_template = V1alpha1DAGTemplate(tasks=[])
         self.template = V1alpha1Template(
@@ -50,7 +58,7 @@ class Workflow:
             parallelism=self.parallelism,
             service_account_name=self.service_account_name,
         )
-        self.metadata = V1ObjectMeta(name=self.name)
+        self.metadata = V1ObjectMeta(name=self.name, labels=self.labels)
         self.spec = V1alpha1WorkflowSpec(
             templates=[self.template], entrypoint=self.name, service_account_name=self.service_account_name
         )
@@ -87,6 +95,12 @@ class Workflow:
                 else:
                     self.spec.volumes.append(t.resources.empty_dir_volume.get_volume())
 
+            if t.resources.secret_volume:
+                if not self.spec.volumes:
+                    self.spec.volumes = [t.resources.secret_volume.get_volume()]
+                else:
+                    self.spec.volumes.append(t.resources.secret_volume.get_volume())
+
             self.dag_template.tasks.append(t.argo_task)
 
     def add_head(self, t: Task, append: bool = True) -> None:
